@@ -33,6 +33,8 @@
 #'   build_aes(df, x = "LET", y = "VAL", geom = "bar") + 
 #'   geom_bar()
 build_aes <- function(data, ..., .list = NULL, geom = NULL) {
+  if (is.null(data))
+    return(aes())
   args <- c(list(...), .list)
   args <- dropNulls(args)
   
@@ -80,6 +82,8 @@ build_aes <- function(data, ..., .list = NULL, geom = NULL) {
 
 make_aes <- function(.list) {
   .list$facet <- NULL
+  .list$facet_row <- NULL
+  .list$facet_col <- NULL
   if (!is.null(.list$xvar)) {
     .list$x <- .list$xvar
     .list$xvar <- NULL
